<?php
use Drupal\views\Entity\View;

/**
 * Implements hook_install().
 */
function idealyzer_install() {
  idealyzer_views_default_views();
}

/**
 * @file
 * Install, update and uninstall functions for the idealyzer module.
 */

/**
 * Implements hook_install().
 */
function idealyzer_install() {
  // Create the site_scanner_results entity table.
  \Drupal::service('entity.definition_update_manager')->applyUpdates();

  // Assign 'administer site scanner results' permission to the appropriate roles.
 // user_role_grant_permissions(DRUPAL_AUTHENTICATED_RID, ['administer site scanner results']);
  //user_role_grant_permissions(DRUPAL_AUTHENTICATED_RID, ['view site scanner results']);
  //user_role_grant_permissions(DRUPAL_ANONYMOUS_RID, ['view site scanner results']);
}

/**
 * Implements hook_uninstall().
 */
function idealyzer_uninstall() {
  // Remove the site_scanner_results entity table.
  \Drupal::service('entity.definition_update_manager')->applyUpdates();
}


/**
 * Implements hook_schema().
 */
function idealyzer_schema() {
  $schema['site_scanner_results'] = [
    'fields' => array(
      'id' => array(
        'type' => 'serial',
        'not null' => TRUE,
        'description' => 'Primary Key: Unique site scanner result ID.',
      ),
      'scan_date' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'The date of the scan.',
      ),
      'target_url_domain' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'The target URL domain.',
      ),
      'final_url' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'The final URL.',
      ),
      'final_url_status_code' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'The status code of the final URL.',
      ),
      'final_url_live' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Whether the final URL is live.',
      ),
      'final_url_media_type' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'The media type of the final URL.',
      ),
      'final_url_same_domain' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Whether the final URL is the same domain.',
      ),
      'final_url_same_website' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Whether the final URL is the same website.',
      ),
      'target_url_404_test' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Whether the target URL returns a 404 status.',
      ),
      'target_url_redirects' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Whether the target URL redirects.',
      ),
      'uswds_usa_classes' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Number of USWDS USA classes.',
      ),
      'uswds_string' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Number of USWDS strings.',
      ),
      'uswds_inpage_css' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Number of USWDS in-page CSS.',
      ),
      'uswds_favicon' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Number of USWDS favicons.',
      ),
      'uswds_string_in_css' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Number of USWDS strings in CSS.',
      ),
      'uswds_favicon_in_css' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Number of USWDS favicons in CSS.',
      ),
      'uswds_publicsans_font' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Number of USWDS PublicSans fonts.',
      ),
      'uswds_semantic_version' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'USWDS semantic version.',
      ),
      'uswds_version' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'USWDS version.',
      ),
      'uswds_count' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Number of USWDS.',
      ),
      'dap' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'DAP status.',
      ),
      'dap_parameters' => array(
        'type' => 'text',
        'not null' => TRUE,
        'description' => 'DAP parameters.',
      ),
      'og_title' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'OG title.',
      ),
      'og_description' => array(
        'type' => 'text',
        'not null' => TRUE,
        'description' => 'OG description.',
      ),
      'og_article_published' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'OG article published date.',
      ),
      'og_article_modified' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'OG article modified date.',
      ),
      'main_element_present' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Main element present status.',
      ),
      'robots_txt_final_url' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'Robots.txt final URL.',
      ),
      'robots_txt_final_url_status_code' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Robots.txt final URL status code.',
      ),
      'robots_txt_final_url_live' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Robots.txt final URL live status.',
      ),
      'robots_txt_detected' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Robots.txt detected status.',
      ),
      'robots_txt_final_url_media_type' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'Robots.txt final URL media type.',
      ),
      'robots_txt_target_url_redirects' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Robots.txt target URL redirects status.',
      ),
      'robots_txt_final_url_filesize' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Robots.txt final URL file size.',
      ),
      'robots_txt_crawl_delay' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Robots.txt crawl delay.',
      ),
      'robots_txt_sitemap_locations' => array(
        'type' => 'text',
        'not null' => TRUE,
        'description' => 'Robots.txt sitemap locations.',
      ),
      'sitemap_xml_detected' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Sitemap.xml detected status.',
      ),
      'sitemap_xml_final_url_status_code' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Sitemap.xml final URL status code.',
      ),
      'sitemap_xml_final_url' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'Sitemap.xml final URL.',
      ),
      'sitemap_xml_final_url_live' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Sitemap.xml final URL live status.',
      ),
      'sitemap_xml_target_url_redirects' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Sitemap.xml target URL redirects status.',
      ),
      'sitemap_xml_final_url_filesize' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Sitemap.xml final URL file size.',
      ),
      'sitemap_xml_final_url_media_type' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'Sitemap.xml final URL media type.',
      ),
      'sitemap_xml_count' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Sitemap.xml count.',
      ),
      'sitemap_xml_pdf_count' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Sitemap.xml PDF count.',
      ),
      'third_party_service_domains' => array(
        'type' => 'text',
        'not null' => TRUE,
        'description' => 'Third-party service domains.',
      ),
      'third_party_service_count' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Third-party service count.',
      ),
      'cookie_domains' => array(
        'type' => 'text',
        'not null' => TRUE,
        'description' => 'Cookie domains.',
      ),
      'ipv6' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'IPv6 status.',
      ),
      'login' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'Login status.',
      ),
      'hostname' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'Hostname.',
      ),
      'final_url_website' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'Final URL website.',
      ),
      'final_url_top_level_domain' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'Final URL top-level domain.',
      ),
      'canonical_link' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'Canonical link.',
      ),
      'cms' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'CMS.',
      ),
      'required_links_url' => array(
        'type' => 'text',
        'not null' => TRUE,
        'description' => 'Required links URL.',
      ),
      'required_links_text' => array(
        'type' => 'text',
        'not null' => TRUE,
        'description' => 'Required links text.',
      ),
      'login_provider' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'Login provider.',
      ),
      'site_search' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Site search status.',
      ),
      'search_dot_gov' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Search.gov status.',
      ),
      'accessibility_scan_status' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Accessibility scan status.',
      ),
      'viewport_meta_tag' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Viewport meta tag status.',
      ),
      'title' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'Title.',
      ),
      'description' => array(
        'type' => 'text',
        'not null' => TRUE,
        'description' => 'Description.',
      ),
      'performance_scan_status' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Performance scan status.',
      ),
      'largest_contentful_paint' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'Largest Contentful Paint.',
      ),
      'cumulative_layout_shift' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'Cumulative Layout Shift.',
      ),
      'keywords' => array(
        'type' => 'text',
        'not null' => TRUE,
        'description' => 'Keywords.',
      ),
      'og_image' => array(
        'type' => 'text',
        'not null' => TRUE,
        'description' => 'OG image.',
      ),
      'og_type' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'OG type.',
      ),
      'og_url' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'OG URL.',
      ),
      'language' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'Language.',
      ),
      'language_link' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'Language link.',
      ),
      'security_scan_status' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Security scan status.',
      ),
      'https_enforced' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'HTTPS enforced status.',
      ),
      'hsts' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'HSTS status.',
      ),
      'uswds_usa_class_list' => array(
        'type' => 'text',
        'not null' => TRUE,
        'description' => 'USWDS USA class list.',
      ),
      'target_url' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'Target URL.',
      ),
      'target_url_top_level_domain' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'Target URL top-level domain.',
      ),
      'target_url_branch' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'Target URL branch.',
      ),
      'target_url_agency_owner' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'Target URL agency owner.',
      ),
      'target_url_bureau_owner' => array(
        'type' => 'varchar',
        'length' => 255,
        'not null' => TRUE,
        'description' => 'Target URL bureau owner.',
      ),
      'source_list' => array(
        'type' => 'text',
        'not null' => TRUE,
        'description' => 'Source list.',
      ),
      'public' => array(
        'type' => 'int',
        'not null' => TRUE,
        'description' => 'Public status.',
      ),
      'scan_data' => array(
        'type' => 'text',
        'not null' => TRUE,
        'description' => 'The raw JSON data of the item.',
      ),
    ),
    'primary key' => array('id'),
  ));
}
