<?php
namespace Drupal\idealyzer\Commands;

use Drush\Commands\DrushCommands;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Defines Drush commands for the idealyzer module.
 */
class IdealyzerCommands extends DrushCommands {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * IdealyzerCommands constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager')
    );
  }

  /**
   * Deletes all site scanner result entities.
   *
   * @command idealyzer:delete-all-site-scanner
   * @aliases dssr
   * @description Deletes all Site Scanner Result entities.
   */
  public function deleteAllSiteScannerResults() {
    $storage = $this->entityTypeManager->getStorage('site_scanner_result');
    $entity_ids = $storage->getQuery()->execute();

    if (!empty($entity_ids)) {
      $entities = $storage->loadMultiple($entity_ids);
      $storage->delete($entities);
      $this->logger()->success(dt('Deleted all Site Scanner Result entities.'));
    }
    else {
      $this->logger()->info(dt('No Site Scanner Result entities found to delete.'));
    }
  }
}
