<?php

namespace Drupal\idealyzer\Controller;

use Symfony\Component\HttpFoundation\Response;
use Drupal\Core\Controller\ControllerBase;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\idealyzer\Entity\SiteScannerResult;
use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;


/**
 * Class SiteScannerResultController.
 */
class SiteScannerResultController extends ControllerBase {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The form builder.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface
   */
  protected $formBuilder;

  /**
   * Constructs a new SiteScannerResultController.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\Core\Form\FormBuilderInterface $form_builder
   *   The form builder.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager, FormBuilderInterface $form_builder) {
    $this->entityTypeManager = $entity_type_manager;
    $this->formBuilder = $form_builder;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('form_builder')
    );
  }

  /**
   * Displays the site scanner results list with the start scan form.
   *
   * @return array
   *   A render array.
   */
  public function listing() {
    $build['start_scan'] = $this->formBuilder->getForm('Drupal\idealyzer\Form\SiteScannerForm');

    $build['table'] = $this->entityTypeManager->getListBuilder('site_scanner_result')->render();

    return $build;
  }

}

