<?php

namespace Drupal\idealyzer\Entity;

use Drupal\Core\Entity\ContentEntityBase;
use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\EntityChangedTrait;
use Drupal\user\EntityOwnerTrait;

/**
 * Defines the SiteScannerResult entity.
 *
 * @ContentEntityType(
 *   id = "site_scanner_result",
 *   label = @Translation("Site Scanner Result"),
 *   handlers = {
 *     "list_builder" = "Drupal\idealyzer\SiteScannerResultListBuilder",
 *     "form" = {
 *       "delete" = "Drupal\idealyzer\Form\SiteScannerResultDeleteForm",
 *     },
 *     "access" = "Drupal\idealyzer\SiteScannerResultAccessControlHandler",
 *   },
 *   base_table = "site_scanner_results",
 *   admin_permission = "administer site scanner results",
 *   entity_keys = {
 *     "id" = "id",
 *     "label" = "target_url_domain",
 *     "uuid" = "uuid"
 *   },
 *   links = {
 *     "canonical" = "/admin/reports/site-scan/{site_scanner_result}",
 *     "add-form" = "/admin/reports/site-scan",
 *     "delete-form" = "/admin/reports/site-scan/{site_scanner_result}/delete",
 *     "collection" = "/admin/reports/site-scan"
 *   },
 * )
 */
class SiteScannerResult extends ContentEntityBase implements SiteScannerResultInterface {

  use EntityChangedTrait;
  use EntityOwnerTrait;

  /**
   * {@inheritdoc}
   */
  public static function baseFieldDefinitions(EntityTypeInterface $entity_type) {
    $fields = parent::baseFieldDefinitions($entity_type);

    $fields['id'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('ID'))
      ->setDescription(t('The ID of the Site Scanner Result entity.'))
      ->setReadOnly(TRUE)
      ->setSetting('unsigned', TRUE)
      ->setSetting('auto_increment', TRUE);

    $fields['scan_data'] = BaseFieldDefinition::create('text_long')
      ->setLabel(t('Scan Data'))
      ->setDescription(t('The raw JSON data of the scan results.'))
      ->setSettings(['default_value' => ''])
      ->setDisplayOptions('view', [
        'label' => 'hidden',
        'type' => 'text_default',
        'weight' => 100,
      ])
      ->setDisplayOptions('form', [
        'type' => 'text_textarea',
        'weight' => 100,
      ]);

    $fields['scan_date'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Scan Date'))
      ->setDescription(t('The date the scan was conducted.'))
      ->setRequired(TRUE)
      ->setReadOnly(TRUE);

    $fields['target_url_domain'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Target URL Domain'))
      ->setDescription(t('The domain of the target URL.'))
      ->setRequired(TRUE)
      ->setReadOnly(TRUE);

    $fields['final_url'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Final URL'))
      ->setDescription(t('The final URL after redirects.'))
      ->setRequired(TRUE)
      ->setReadOnly(TRUE);

    $fields['final_url_status_code'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Final URL Status Code'))
      ->setDescription(t('The status code of the final URL.'))
      ->setRequired(TRUE)
      ->setReadOnly(TRUE);

    $fields['final_url_live'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Final URL Live'))
      ->setDescription(t('Whether the final URL is live.'))
      ->setRequired(TRUE)
      ->setReadOnly(TRUE);

    $fields['final_url_media_type'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Final URL Media Type'))
      ->setDescription(t('The media type of the final URL.'))
      ->setRequired(TRUE)
      ->setReadOnly(TRUE);

    $fields['final_url_same_domain'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Final URL Same Domain'))
      ->setDescription(t('Whether the final URL is in the same domain.'))
      ->setRequired(TRUE)
      ->setReadOnly(TRUE);

    $fields['final_url_same_website'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Final URL Same Website'))
      ->setDescription(t('Whether the final URL is in the same website.'))
      ->setRequired(TRUE)
      ->setReadOnly(TRUE);

    $fields['target_url_404_test'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Target URL 404 Test'))
      ->setDescription(t('Result of the target URL 404 test.'))
      ->setRequired(TRUE)
      ->setReadOnly(TRUE);

    $fields['target_url_redirects'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Target URL Redirects'))
      ->setDescription(t('Number of redirects for the target URL.'))
      ->setRequired(TRUE)
      ->setReadOnly(TRUE);

    $fields['uswds_usa_classes'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('USWDS USA Classes'))
      ->setDescription(t('Number of USWDS USA classes found.'))
      ->setRequired(TRUE)
      ->setReadOnly(TRUE);

    $fields['uswds_string'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('USWDS String'))
      ->setDescription(t('Number of USWDS strings found.'))
      ->setRequired(TRUE)
      ->setReadOnly(TRUE);

    $fields['uswds_inpage_css'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('USWDS In-page CSS'))
      ->setDescription(t('Number of USWDS in-page CSS found.'))
      ->setRequired(TRUE)
      ->setReadOnly(TRUE);

    $fields['uswds_favicon'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('USWDS Favicon'))
      ->setDescription(t('Number of USWDS favicons found.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['uswds_string_in_css'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('USWDS String in CSS'))
      ->setDescription(t('Number of USWDS strings in CSS found.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['uswds_favicon_in_css'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('USWDS Favicon in CSS'))
      ->setDescription(t('Number of USWDS favicons in CSS found.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['uswds_publicsans_font'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('USWDS Public Sans Font'))
      ->setDescription(t('Number of USWDS Public Sans fonts found.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['uswds_semantic_version'] = BaseFieldDefinition::create('string')
      ->setLabel(t('USWDS Semantic Version'))
      ->setDescription(t('The semantic version of USWDS.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['uswds_version'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('USWDS Version'))
      ->setDescription(t('The version of USWDS.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['uswds_count'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('USWDS Count'))
      ->setDescription(t('The count of USWDS components found.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['dap'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('DAP'))
      ->setDescription(t('Number of DAP (Digital Analytics Program) scripts found.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['dap_parameters'] = BaseFieldDefinition::create('text_long')
      ->setLabel(t('DAP Parameters'))
      ->setDescription(t('The parameters for DAP.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['og_title'] = BaseFieldDefinition::create('string')
      ->setLabel(t('OG Title'))
      ->setDescription(t('The Open Graph title.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['og_description'] = BaseFieldDefinition::create('text_long')
      ->setLabel(t('OG Description'))
      ->setDescription(t('The Open Graph description.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['og_article_published'] = BaseFieldDefinition::create('string')
      ->setLabel(t('OG Article Published'))
      ->setDescription(t('The Open Graph article published date.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['og_article_modified'] = BaseFieldDefinition::create('string')
      ->setLabel(t('OG Article Modified'))
      ->setDescription(t('The Open Graph article modified date.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['main_element_present'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Main Element Present'))
      ->setDescription(t('Whether the main element is present.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['robots_txt_final_url'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Robots.txt Final URL'))
      ->setDescription(t('The final URL of robots.txt.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['robots_txt_final_url_status_code'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Robots.txt Final URL Status Code'))
      ->setDescription(t('The status code of the robots.txt final URL.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['robots_txt_final_url_live'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Robots.txt Final URL Live'))
      ->setDescription(t('Whether the robots.txt final URL is live.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['robots_txt_detected'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Robots.txt Detected'))
      ->setDescription(t('Whether robots.txt was detected.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['robots_txt_final_url_media_type'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Robots.txt Final URL Media Type'))
      ->setDescription(t('The media type of the robots.txt final URL.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['robots_txt_target_url_redirects'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Robots.txt Target URL Redirects'))
      ->setDescription(t('Number of redirects for the robots.txt target URL.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['robots_txt_final_url_filesize'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Robots.txt Final URL Filesize'))
      ->setDescription(t('The filesize of the robots.txt final URL.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['robots_txt_crawl_delay'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Robots.txt Crawl Delay'))
      ->setDescription(t('The crawl delay specified in the robots.txt.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['robots_txt_sitemap_locations'] = BaseFieldDefinition::create('text_long')
      ->setLabel(t('Robots.txt Sitemap Locations'))
      ->setDescription(t('The sitemap locations specified in the robots.txt.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['sitemap_xml_detected'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Sitemap.xml Detected'))
      ->setDescription(t('Whether sitemap.xml was detected.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['sitemap_xml_final_url_status_code'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Sitemap.xml Final URL Status Code'))
      ->setDescription(t('The status code of the sitemap.xml final URL.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['sitemap_xml_final_url'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Sitemap.xml Final URL'))
      ->setDescription(t('The final URL of sitemap.xml.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['sitemap_xml_final_url_live'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Sitemap.xml Final URL Live'))
      ->setDescription(t('Whether the sitemap.xml final URL is live.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['sitemap_xml_target_url_redirects'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Sitemap.xml Target URL Redirects'))
      ->setDescription(t('Number of redirects for the sitemap.xml target URL.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['sitemap_xml_final_url_filesize'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Sitemap.xml Final URL Filesize'))
      ->setDescription(t('The filesize of the sitemap.xml final URL.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['sitemap_xml_final_url_media_type'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Sitemap.xml Final URL Media Type'))
      ->setDescription(t('The media type of the sitemap.xml final URL.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['sitemap_xml_count'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Sitemap.xml Count'))
      ->setDescription(t('The count of sitemap.xml components found.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['sitemap_xml_pdf_count'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Sitemap.xml PDF Count'))
      ->setDescription(t('The count of PDF files in the sitemap.xml.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['third_party_service_domains'] = BaseFieldDefinition::create('text_long')
      ->setLabel(t('Third-party Service Domains'))
      ->setDescription(t('The third-party service domains found.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['third_party_service_count'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Third-party Service Count'))
      ->setDescription(t('The count of third-party services found.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['cookie_domains'] = BaseFieldDefinition::create('text_long')
      ->setLabel(t('Cookie Domains'))
      ->setDescription(t('The cookie domains found.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['ipv6'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('IPv6'))
      ->setDescription(t('Whether IPv6 is supported.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['login'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Login'))
      ->setDescription(t('Login information.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['hostname'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Hostname'))
      ->setDescription(t('The hostname.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['final_url_website'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Final URL Website'))
      ->setDescription(t('The website of the final URL.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['final_url_top_level_domain'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Final URL Top-level Domain'))
      ->setDescription(t('The top-level domain of the final URL.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['canonical_link'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Canonical Link'))
      ->setDescription(t('The canonical link.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['cms'] = BaseFieldDefinition::create('string')
      ->setLabel(t('CMS'))
      ->setDescription(t('The content management system used.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['required_links_url'] = BaseFieldDefinition::create('text_long')
      ->setLabel(t('Required Links URL'))
      ->setDescription(t('The required links URL.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['required_links_text'] = BaseFieldDefinition::create('text_long')
      ->setLabel(t('Required Links Text'))
      ->setDescription(t('The required links text.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['login_provider'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Login Provider'))
      ->setDescription(t('The login provider.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['site_search'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Site Search'))
      ->setDescription(t('Whether site search is enabled.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['search_dot_gov'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Search.gov'))
      ->setDescription(t('Whether search.gov is used.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['accessibility_scan_status'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Accessibility Scan Status'))
      ->setDescription(t('The status of the accessibility scan.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

$fields['security_scan_status'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Security Scan Status'))
      ->setDescription(t('The status of the security scan.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

$fields['performance_scan_status'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Performance Scan Status'))
      ->setDescription(t('The status of the performance scan.'))
      ->setRequired(TRUE)
      ->setReadOnly(TRUE);

      $fields['dns_scan_status'] = BaseFieldDefinition::create('string')
      ->setLabel(t('DNS Scan Status'))
      ->setDescription(t('The status of the DNS scan.'))
      ->setRequired(TRUE)
      ->setReadOnly(TRUE);

      $fields['sitemap_xml_scan_status'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Sitemap XML Scan Status'))
      ->setDescription(t('The status of the sitemap scan.'))
      ->setRequired(TRUE)
      ->setReadOnly(TRUE);
      $fields['robots_txt_scan_status'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Robots Txt Scan Status'))
      ->setDescription(t('The status of the robots txt scan.'))
      ->setRequired(TRUE)
      ->setReadOnly(TRUE);
      $fields['primary_scan_status'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Primary Scan Status'))
      ->setDescription(t('The status of the primary scan.'))
      ->setRequired(TRUE)
      ->setReadOnly(TRUE);
      $fields['not_found_scan_status'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Not found Scan Status'))
      ->setDescription(t('The status of the not found scan.'))
      ->setRequired(TRUE)
      ->setReadOnly(TRUE);

    $fields['viewport_meta_tag'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Viewport Meta Tag'))
      ->setDescription(t('Whether the viewport meta tag is present.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['title'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Title'))
      ->setDescription(t('The title of the page.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['description'] = BaseFieldDefinition::create('text_long')
      ->setLabel(t('Description'))
      ->setDescription(t('The description of the page.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['largest_contentful_paint'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Largest Contentful Paint'))
      ->setDescription(t('The largest contentful paint time.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['cumulative_layout_shift'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Cumulative Layout Shift'))
      ->setDescription(t('The cumulative layout shift.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['keywords'] = BaseFieldDefinition::create('text_long')
      ->setLabel(t('Keywords'))
      ->setDescription(t('The keywords of the page.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['og_image'] = BaseFieldDefinition::create('string')
      ->setLabel(t('OG Image'))
      ->setDescription(t('The Open Graph image URL.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['og_type'] = BaseFieldDefinition::create('string')
      ->setLabel(t('OG Type'))
      ->setDescription(t('The Open Graph type.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['og_url'] = BaseFieldDefinition::create('string')
      ->setLabel(t('OG URL'))
      ->setDescription(t('The Open Graph URL.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['language'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Language'))
      ->setDescription(t('The language of the page.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['language_link'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Language Link'))
      ->setDescription(t('The link to the language page.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['https_enforced'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('HTTPS Enforced'))
      ->setDescription(t('Whether HTTPS is enforced.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['hsts'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('HSTS'))
      ->setDescription(t('Whether HSTS is enabled.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['uswds_usa_class_list'] = BaseFieldDefinition::create('text_long')
      ->setLabel(t('USWDS USA Class List'))
      ->setDescription(t('List of USWDS USA classes found.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['target_url'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Target URL'))
      ->setDescription(t('The target URL.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['target_url_top_level_domain'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Target URL Top-level Domain'))
      ->setDescription(t('The top-level domain of the target URL.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['target_url_branch'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Target URL Branch'))
      ->setDescription(t('The branch of the target URL.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['target_url_agency_owner'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Target URL Agency Owner'))
      ->setDescription(t('The agency owner of the target URL.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['target_url_bureau_owner'] = BaseFieldDefinition::create('string')
      ->setLabel(t('Target URL Bureau Owner'))
      ->setDescription(t('The bureau owner of the target URL.'))
      ->setRequired(TRUE)
->setReadOnly(TRUE);

    $fields['source_list'] = BaseFieldDefinition::create('text_long')
      ->setLabel(t('Source List'))
      ->setDescription(t('The source list.'))
      ->setRequired(TRUE)
      ->setReadOnly(TRUE);

    $fields['public'] = BaseFieldDefinition::create('integer')
      ->setLabel(t('Public'))
      ->setDescription(t('Whether the page is public.'))
      ->setRequired(TRUE)
      ->setReadOnly(TRUE);

    return $fields;
  }

}
