<?php

namespace Drupal\idealyzer\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

class ApiConfigForm extends ConfigFormBase {

  protected function getEditableConfigNames() {
    return ['idealyzer.settings'];
  }

  public function getFormId() {
    return 'idealyzer_api_config_form';
  }

  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('idealyzer.settings');
    $api_key = $config->get('api_key');

    $form['api_key'] = [
      '#type' => 'password',
      '#title' => $this->t('API Key'),
      '#description' => $this->t('Enter the API key. The key will be stored securely.'),
      '#required' => TRUE,
      '#attributes' => [
        'placeholder' => $api_key ? str_repeat('*', strlen($api_key)) : '',
      ],
    ];

    return parent::buildForm($form, $form_state);
  }

  public function submitForm(array &$form, FormStateInterface $form_state) {
    $apiKey = $form_state->getValue('api_key');
    $config = $this->config('idealyzer.settings');
    $storedApiKey = $config->get('api_key');

    // Only update the stored API key if a new key is provided.
    if ($apiKey && $apiKey !== str_repeat('*', strlen($storedApiKey))) {
      $config->set('api_key', $apiKey)->save();
      $this->messenger()->addStatus($this->t('API Key has been updated.'));
    } elseif ($apiKey === str_repeat('*', strlen($storedApiKey)) && !$storedApiKey) {
      // Handle case where masked value is submitted but no key was previously stored.
      $this->messenger()->addError($this->t('API Key cannot be empty.'));
    } else {
      $this->messenger()->addStatus($this->t('API Key has not been changed.'));
    }

    parent::submitForm($form, $form_state);
  }
}
