<?php

namespace Drupal\idealyzer\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\idealyzer\Service\SiteScannerService;
use Symfony\Component\DependencyInjection\ContainerInterface;

class SiteScannerForm extends FormBase {

  protected $siteScannerService;

  public function __construct(SiteScannerService $siteScannerService) {
    $this->siteScannerService = $siteScannerService;
  }

  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('idealyzer.site_scanner')
    );
  }

  public function getFormId() {
    return 'idealyzer_site_scanner_form';
  }

  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['#attached']['library'][] = 'core/drupal.dialog.ajax';

    $form['url'] = [
      '#type' => 'textfield',
      '#title' => $this->t('URL'),
      '#required' => TRUE,
    ];

    $form['actions']['#type'] = 'actions';

    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Scan Site'),
      '#button_type' => 'primary',
    ];

    $form['actions']['delete'] = [
      '#type' => 'submit',
      '#value' => $this->t('Delete All Scans'),
      '#button_type' => 'danger',
      '#submit' => ['::deleteAllScans'],
      '#limit_validation_errors' => [],
    ];

    return $form;
  }

  public function submitForm(array &$form, FormStateInterface $form_state) {
    $url = $form_state->getValue('url');
    $this->siteScannerService->fetchAndSaveResults($url);
    $this->messenger()->addMessage($this->t('Scanning initiated for URL: @url', ['@url' => $url]));
  }

  public function deleteAllScans(array &$form, FormStateInterface $form_state) {
    \Drupal::entityTypeManager()->getStorage('site_scanner_result')->delete(\Drupal::entityTypeManager()->getStorage('site_scanner_result')->loadMultiple());
    $this->messenger()->addMessage($this->t('All scans have been deleted.'));
  }

}
